<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression Error</source>
        <translation>Błąd wyrażenia matematycznego</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Dark Theme</source>
        <translation>Motyw ciemny</translation>
    </message>
    <message>
        <source>Simple mode</source>
        <translation>Tryb prosty</translation>
    </message>
    <message>
        <source>Scientific mode</source>
        <translation>Tryb naukowy</translation>
    </message>
    <message>
        <source>Deepin Calculator</source>
        <translation>Kalkulator Deepin</translation>
    </message>
    <message>
        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
        <translation>Kalkulator Deepin to prosty i łatwy w użyciu kalkulator biurkowy. Obsługuje operacje dodawania, odejmowania, mnożenia i dzielenia.</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression Error</source>
        <translation>Błąd wyrażenia matematycznego</translation>
    </message>
</context>
</TS>